@@ -14,7 +14,7 @@ from typing import (  # type: ignore[attr-defined]
 )
 from typing_extensions import Annotated, Self, get_args, get_origin
 
-from strawberry.exceptions import StrawberryException
+from strawberry.exceptions.not_a_strawberry_enum import NotAStrawberryEnumError
 from strawberry.private import is_private
 
 
@@ -179,7 +179,7 @@ class StrawberryAnnotation:
         try:
             return evaled_type._enum_definition
         except AttributeError:
-            raise StrawberryException(f"{evaled_type} fields cannot be resolved.")
+            raise NotAStrawberryEnumError(evaled_type)
 
     def create_list(self, evaled_type: Any) -> StrawberryList:
         of_type = StrawberryAnnotation(
