@@ -15,7 +15,7 @@ from typing import (
 
 from graphql import GraphQLScalarType
 
-from strawberry.exceptions import InvalidUnionType
+from strawberry.exceptions import InvalidUnionTypeError
 from strawberry.type import StrawberryOptional, StrawberryType
 
 from .utils.str_converters import to_camel_case
@@ -46,6 +46,10 @@ class ScalarDefinition(StrawberryType):
     # duplicates
     implementation: Optional[GraphQLScalarType] = None
 
+    # used for better error messages
+    _source_file: Optional[str] = None
+    _source_line: Optional[int] = None
+
     def copy_with(
         self, type_var_map: Mapping[TypeVar, Union[StrawberryType, type]]
     ) -> Union[StrawberryType, type]:
@@ -59,7 +63,7 @@ class ScalarDefinition(StrawberryType):
 class ScalarWrapper:
     _scalar_definition: ScalarDefinition
 
-    def __init__(self, wrap):
+    def __init__(self, wrap: Callable[[Any], Any]):
         self.wrap = wrap
 
     def __call__(self, *args, **kwargs):
@@ -73,7 +77,7 @@ class ScalarWrapper:
         # Raise an error in any other case.
         # There is Work in progress to deal with more merging cases, see:
         # https://github.com/strawberry-graphql/strawberry/pull/1455
-        raise InvalidUnionType(other)
+        raise InvalidUnionTypeError(str(other), self.wrap)
 
 
 def _process_scalar(
@@ -87,8 +91,19 @@ def _process_scalar(
     parse_literal: Optional[Callable] = None,
     directives: Iterable[object] = (),
 ):
+    from strawberry.exceptions.handler import should_use_rich_exceptions
+
     name = name or to_camel_case(cls.__name__)
 
+    _source_file = None
+    _source_line = None
+
+    if should_use_rich_exceptions():
+        frame = sys._getframe(3)
+
+        _source_file = frame.f_code.co_filename
+        _source_line = frame.f_lineno
+
     wrapper = ScalarWrapper(cls)
     wrapper._scalar_definition = ScalarDefinition(
         name=name,
@@ -98,6 +113,8 @@ def _process_scalar(
         parse_literal=parse_literal,
         parse_value=parse_value,
         directives=directives,
+        _source_file=_source_file,
+        _source_line=_source_line,
     )
 
     return wrapper
