@@ -13,14 +13,10 @@ from typing import (
     cast,
 )
 
-from graphql import (
-    ExecutionContext as GraphQLExecutionContext,
-    ExecutionResult as GraphQLExecutionResult,
-    GraphQLError,
-    GraphQLSchema,
-    execute as original_execute,
-    parse,
-)
+from graphql import ExecutionContext as GraphQLExecutionContext
+from graphql import ExecutionResult as GraphQLExecutionResult
+from graphql import GraphQLError, GraphQLSchema, parse
+from graphql import execute as original_execute
 from graphql.language import DocumentNode
 from graphql.validation import ASTValidationRule, validate
 
@@ -86,6 +82,7 @@ async def execute(
 
             except GraphQLError as error:
                 execution_context.errors = [error]
+                process_errors([error], execution_context)
                 return ExecutionResult(
                     data=None,
                     errors=[error],
@@ -96,6 +93,8 @@ async def execute(
                 error = GraphQLError(str(error), original_error=error)
 
                 execution_context.errors = [error]
+                process_errors([error], execution_context)
+
                 return ExecutionResult(
                     data=None,
                     errors=[error],
@@ -108,6 +107,7 @@ async def execute(
         async with extensions_runner.validation():
             _run_validation(execution_context)
             if execution_context.errors:
+                process_errors(execution_context.errors, execution_context)
                 return ExecutionResult(data=None, errors=execution_context.errors)
 
         async with extensions_runner.executing():
@@ -172,6 +172,7 @@ def execute_sync(
 
             except GraphQLError as error:
                 execution_context.errors = [error]
+                process_errors([error], execution_context)
                 return ExecutionResult(
                     data=None,
                     errors=[error],
@@ -182,6 +183,7 @@ def execute_sync(
                 error = GraphQLError(str(error), original_error=error)
 
                 execution_context.errors = [error]
+                process_errors([error], execution_context)
                 return ExecutionResult(
                     data=None,
                     errors=[error],
@@ -194,6 +196,7 @@ def execute_sync(
         with extensions_runner.validation():
             _run_validation(execution_context)
             if execution_context.errors:
+                process_errors(execution_context.errors, execution_context)
                 return ExecutionResult(data=None, errors=execution_context.errors)
 
         with extensions_runner.executing():
