@@ -13,6 +13,7 @@ from graphql import (
 from graphql.subscription import subscribe
 from graphql.type.directives import specified_directives
 
+from strawberry.annotation import StrawberryAnnotation
 from strawberry.custom_scalar import ScalarDefinition, ScalarWrapper
 from strawberry.directive import StrawberryDirective
 from strawberry.enum import EnumDefinition
@@ -105,6 +106,9 @@ class Schema(BaseSchema):
                     self.schema_converter.from_schema_directive(type_)
                 )
             else:
+                if hasattr(type_, "_type_definition"):
+                    if type_._type_definition.is_generic:
+                        type_ = StrawberryAnnotation(type_).resolve()
                 graphql_type = self.schema_converter.from_maybe_optional(type_)
                 if isinstance(graphql_type, GraphQLNonNull):
                     graphql_type = graphql_type.of_type
@@ -123,7 +127,12 @@ class Schema(BaseSchema):
                     GraphQLCoreConverter.DEFINITION_BACKREF: self,
                 },
             )
+
         except TypeError as error:
+            # GraphQL core throws a TypeError if there's any exception raised
+            # during the schema creation, so we check if the cause was a
+            # StrawberryError and raise it instead if that's the case.
+
             from strawberry.exceptions import StrawberryException
 
             if isinstance(error.__cause__, StrawberryException):
